@@ -1,10 +1,10 @@
 from __future__ import with_statement
 
-import hashlib
 import os
 import posixpath
 import stat
 import re
+import uuid
 from fnmatch import filter as fnfilter
 
 from fabric.state import output, connections, env
@@ -62,7 +62,7 @@ class SFTP(object):
         rlist = self.ftp.listdir(dirpart)
 
         names = fnfilter([f for f in rlist if not f[0] == '.'], pattern)
-        ret = [path]
+        ret = []
         if len(names):
             s = '/'
             ret = [dirpart.rstrip(s) + s + name.lstrip(s) for name in names]
@@ -130,9 +130,10 @@ class SFTP(object):
         }
 
         if local_is_path:
-            # Naive fix to issue #711
-            escaped_path = re.sub(r'(%[^()]*\w)', r'%\1', local_path)
-            local_path = os.path.abspath(escaped_path % path_vars )
+            # Fix for issue #711 and #1348 - escape %'s as well as possible.
+            format_re = r'(%%(?!\((?:%s)\)\w))' % '|'.join(path_vars.keys())
+            escaped_path = re.sub(format_re, r'%\1', local_path)
+            local_path = os.path.abspath(escaped_path % path_vars)
 
             # Ensure we give ssh.SFTPCLient a file by prepending and/or
             # creating local directories as appropriate.
@@ -157,11 +158,7 @@ class SFTP(object):
         # path in the default remote CWD (which, typically, the login user will
         # have write permissions on) in order to sudo(cp) it.
         if use_sudo:
-            target_path = remote_path
-            hasher = hashlib.sha1()
-            hasher.update(env.host_string)
-            hasher.update(target_path)
-            target_path = posixpath.join(temp_dir, hasher.hexdigest())
+            target_path = posixpath.join(temp_dir, uuid.uuid4().hex)
             # Temporarily nuke 'cwd' so sudo() doesn't "cd" its mv command.
             # (The target path has already been cwd-ified elsewhere.)
             with settings(hide('everything'), cwd=""):
@@ -249,10 +246,7 @@ class SFTP(object):
         # have write permissions on) in order to sudo(mv) it later.
         if use_sudo:
             target_path = remote_path
-            hasher = hashlib.sha1()
-            hasher.update(env.host_string)
-            hasher.update(target_path)
-            remote_path = posixpath.join(temp_dir, hasher.hexdigest())
+            remote_path = posixpath.join(temp_dir, uuid.uuid4().hex)
         # Read, ensuring we handle file-like objects correct re: seek pointer
         putter = self.ftp.put
         if not local_is_path:
